[Libreoffice-commits] core.git: 15 commits - basctl/source cui/source dbaccess/source include/svtools include/svx sc/source sd/source sfx2/source svtools/source svx/source sw/source vcl/source

Caolán McNamara caolanm at redhat.com
Tue Apr 8 01:19:11 PDT 2014


 basctl/source/basicide/moduldlg.cxx                |   14 +---
 basctl/source/basicide/moduldlg.hxx                |    6 -
 cui/source/customize/cfg.cxx                       |   26 ++++----
 cui/source/inc/cfg.hxx                             |    8 +-
 dbaccess/source/ui/querydesign/QueryDesignView.cxx |    4 -
 include/svtools/editbrowsebox.hxx                  |    6 +
 include/svtools/svparser.hxx                       |    9 ++
 include/svtools/treelistbox.hxx                    |    8 +-
 include/svx/swframevalidation.hxx                  |    5 +
 sc/source/ui/dbgui/PivotLayoutTreeListBase.cxx     |    8 +-
 sc/source/ui/inc/PivotLayoutTreeListBase.hxx       |    4 -
 sd/source/ui/dlg/sdtreelb.cxx                      |   12 ---
 sd/source/ui/inc/sdtreelb.hxx                      |    2 
 sfx2/source/appl/imestatuswindow.cxx               |    2 
 sfx2/source/dialog/templdlg.cxx                    |    8 --
 sfx2/source/inc/templdgi.hxx                       |    2 
 sfx2/source/view/sfxbasecontroller.cxx             |    3 
 svtools/source/contnr/treelistbox.cxx              |   30 ++++-----
 svx/source/svdraw/svdundo.cxx                      |    7 --
 svx/source/table/tableundo.cxx                     |    1 
 sw/source/core/uibase/app/appopt.cxx               |   66 +++++----------------
 sw/source/core/uibase/inc/conttree.hxx             |    8 +-
 sw/source/core/uibase/inc/glossary.hxx             |    6 -
 sw/source/core/uibase/utlui/content.cxx            |    8 +-
 sw/source/core/uibase/utlui/glbltree.cxx           |    9 +-
 sw/source/filter/ww8/ww8par6.cxx                   |    2 
 sw/source/ui/dialog/docstdlg.cxx                   |    3 
 sw/source/ui/fldui/fldedt.cxx                      |    8 +-
 sw/source/ui/misc/glossary.cxx                     |    8 +-
 vcl/source/gdi/pdfwriter_impl.cxx                  |    1 
 30 files changed, 133 insertions(+), 151 deletions(-)

New commits:
commit ceb199692c42d86903bc4e7df11fa895c92e95c1
Author: Caolán McNamara <caolanm at redhat.com>
Date:   Mon Apr 7 21:24:34 2014 +0100

    coverity#708385 Uninitialized scalar field
    
    Change-Id: I9150f0849099650f35611015e26754fd6b05ed79

diff --git a/svx/source/svdraw/svdundo.cxx b/svx/source/svdraw/svdundo.cxx
index c1cbe64..f7fca4d 100644
--- a/svx/source/svdraw/svdundo.cxx
+++ b/svx/source/svdraw/svdundo.cxx
@@ -1768,11 +1768,10 @@ OUString SdrUndoPageRemoveMasterPage::GetComment() const
     return aStr;
 }
 
-
-
 SdrUndoPageChangeMasterPage::SdrUndoPageChangeMasterPage(SdrPage& rChangedPage)
-:   SdrUndoPageMasterPage(rChangedPage),
-    mbNewHadMasterPage(false)
+    : SdrUndoPageMasterPage(rChangedPage)
+    , mbNewHadMasterPage(false)
+    , maNewMasterPageNumber(0)
 {
 }
 
commit 409ebeb20d1ee4552ac21bd739ae4e25eaeb68d9
Author: Caolán McNamara <caolanm at redhat.com>
Date:   Mon Apr 7 21:22:18 2014 +0100

    coverity#708388 Uninitialized scalar field
    
    Change-Id: Idaa2ec4863beb6be790022c3c66bc4a72e9bf626

diff --git a/svx/source/table/tableundo.cxx b/svx/source/table/tableundo.cxx
index c406a48..358691c 100644
--- a/svx/source/table/tableundo.cxx
+++ b/svx/source/table/tableundo.cxx
@@ -511,6 +511,7 @@ void TableRowUndo::getData( Data& rData )
 TableStyleUndo::TableStyleUndo( const SdrTableObj& rTableObj )
     : SdrUndoAction( *rTableObj.GetModel() )
     , mxObjRef( const_cast< sdr::table::SdrTableObj*>( &rTableObj ) )
+    , mbHasRedoData(false)
 {
     getData( maUndoData );
 }
commit b19e943c50e5f9f436a2dc616c661e19c8152bb1
Author: Caolán McNamara <caolanm at redhat.com>
Date:   Mon Apr 7 21:18:46 2014 +0100

    coverity#708175 Uninitialized scalar field
    
    Change-Id: I235f46bf9b0e672ddad16d9766a09f5c7c88a3e0

diff --git a/sfx2/source/view/sfxbasecontroller.cxx b/sfx2/source/view/sfxbasecontroller.cxx
index 64ec9ea..d6ec618 100644
--- a/sfx2/source/view/sfxbasecontroller.cxx
+++ b/sfx2/source/view/sfxbasecontroller.cxx
@@ -198,6 +198,9 @@ public:
                             SfxStatusIndicator(SfxBaseController* pController, SfxWorkWindow* pWork)
                                 : xOwner( pController )
                                 , pWorkWindow( pWork )
+                                , _nRange(0)
+                                , _nValue(0)
+                                , _nStartTime(0)
                             {
                                 ++m_refCount;
                                 Reference< lang::XComponent > xComponent(
commit e1fcf731fdb8457c9c8b686d182e4b2dbb7ff1bb
Author: Caolán McNamara <caolanm at redhat.com>
Date:   Mon Apr 7 21:17:01 2014 +0100

    coverity#708193 Uninitialized scalar field
    
    Change-Id: Ibf9f267acf3bef7aa0ce34660664f095453f4b82

diff --git a/include/svtools/editbrowsebox.hxx b/include/svtools/editbrowsebox.hxx
index 4ea02f9..b5157e9 100644
--- a/include/svtools/editbrowsebox.hxx
+++ b/include/svtools/editbrowsebox.hxx
@@ -452,7 +452,11 @@ namespace svt
             bool               bDown;
 
         public:
-            BrowserMouseEventPtr():pEvent(NULL){}
+            BrowserMouseEventPtr()
+                : pEvent(NULL)
+                , bDown(false)
+            {
+            }
             ~BrowserMouseEventPtr(){Clear();}
 
             bool Is() const {return pEvent != NULL;}
commit 5691af7977831d8c5fcdcb68e7a1e3547de45e51
Author: Caolán McNamara <caolanm at redhat.com>
Date:   Mon Apr 7 21:15:57 2014 +0100

    coverity#708197 Uninitialized scalar field
    
    Change-Id: Ied5ed708b60fe63288ca2ef1b50a7091dd7dbd2e

diff --git a/include/svtools/svparser.hxx b/include/svtools/svparser.hxx
index 3e21473e..c26a244 100644
--- a/include/svtools/svparser.hxx
+++ b/include/svtools/svparser.hxx
@@ -84,8 +84,13 @@ protected:
         bool        bTokenHasValue;
         int         nTokenId;
 
-        inline TokenStackType() { nTokenId = 0; }
-        inline ~TokenStackType() { }
+        TokenStackType()
+            : nTokenValue(0)
+            , bTokenHasValue(0)
+            , nTokenId(0)
+        {
+        }
+        ~TokenStackType() { }
     };
 
     // Methoden fuer Token-Stack
commit 190e3f7f51b1e382adc9cb18d6ec23dc20584239
Author: Caolán McNamara <caolanm at redhat.com>
Date:   Mon Apr 7 21:14:23 2014 +0100

    coverity#708202 Uninitialized scalar field
    
    Change-Id: Ie73377009a2aefd4ec18adafc61e56076b8c3c9a

diff --git a/include/svx/swframevalidation.hxx b/include/svx/swframevalidation.hxx
index ee50529..6ae77fe 100644
--- a/include/svx/swframevalidation.hxx
+++ b/include/svx/swframevalidation.hxx
@@ -56,6 +56,11 @@ struct SvxSwFrameValidation
     Size    aPercentSize;   // Size for 100% value
 
     SvxSwFrameValidation() :
+        nAnchorType(0),
+        nHoriOrient(0),
+        nVertOrient(0),
+        nHRelOrient(0),
+        nVRelOrient(0),
         bAutoHeight(false),
         bAutoWidth(false),
         bMirror(false),
commit 27902363384d7dd0ccc5cec2cc71a8549485ca4f
Author: Caolán McNamara <caolanm at redhat.com>
Date:   Mon Apr 7 21:08:06 2014 +0100

    coverity#736070 Missing break in switch
    
    Change-Id: I924d1316483883f7d1ecb145eef38833d1dc70ce

diff --git a/sw/source/filter/ww8/ww8par6.cxx b/sw/source/filter/ww8/ww8par6.cxx
index 92f423a..d466e84 100644
--- a/sw/source/filter/ww8/ww8par6.cxx
+++ b/sw/source/filter/ww8/ww8par6.cxx
@@ -165,6 +165,7 @@ void wwSection::SetDirection()
     {
         default:
             OSL_ENSURE(!this, "Unknown layout type");
+            //fall-through
         case 0:
             meDir=FRMDIR_HORI_LEFT_TOP;
             break;
commit 5459a21f2fedf0a6e720fa853440c64f6660cdb1
Author: Caolán McNamara <caolanm at redhat.com>
Date:   Mon Apr 7 21:07:12 2014 +0100

    coverity#736069 Missing break in switch
    
    Change-Id: I363f634454e72d37c82494242b195b1a9f8454b2

diff --git a/sw/source/filter/ww8/ww8par6.cxx b/sw/source/filter/ww8/ww8par6.cxx
index 2df5e39..92f423a 100644
--- a/sw/source/filter/ww8/ww8par6.cxx
+++ b/sw/source/filter/ww8/ww8par6.cxx
@@ -239,6 +239,7 @@ void SwWW8ImplReader::SetDocumentGrid(SwFrmFmt &rFmt, const wwSection &rSection)
             break;
         default:
             OSL_ENSURE(!this, "Unknown grid type");
+            //fall-through
         case 3:
             eType = GRID_LINES_CHARS;
             aGrid.SetSnapToChars(sal_True);
commit 2ea89ac63fa83b09807581d24ebd441776abb358
Author: Caolán McNamara <caolanm at redhat.com>
Date:   Mon Apr 7 21:06:04 2014 +0100

    coverity#705329 Missing break in switch
    
    Change-Id: I3718c2960dc0a7f760c3c7749417c1e497b7e04e

diff --git a/vcl/source/gdi/pdfwriter_impl.cxx b/vcl/source/gdi/pdfwriter_impl.cxx
index c37f416..cb8b0b3 100644
--- a/vcl/source/gdi/pdfwriter_impl.cxx
+++ b/vcl/source/gdi/pdfwriter_impl.cxx
@@ -5285,6 +5285,7 @@ bool PDFWriterImpl::emitWidgetAnnotations()
                         else
                             appendName( rWidget.m_aValue, aValue );
                     }
+                    // fall-through
                 case PDFWriter::PushButton:
                     aLine.append( "Btn" );
                     break;
commit d546224464df4fcc85ad978fa149d876d093d714
Author: Caolán McNamara <caolanm at redhat.com>
Date:   Mon Apr 7 20:48:30 2014 +0100

    coverity#705015 Explicit null dereferenced
    
    Change-Id: Idac9493e152f639066cf497be897b8a489c39f6c

diff --git a/sw/source/ui/fldui/fldedt.cxx b/sw/source/ui/fldui/fldedt.cxx
index 053ea40..65e5c99 100644
--- a/sw/source/ui/fldui/fldedt.cxx
+++ b/sw/source/ui/fldui/fldedt.cxx
@@ -183,9 +183,13 @@ SfxTabPage* SwFldEditDlg::CreatePage(sal_uInt16 nGroup)
 
     }
 
-    static_cast<SwFldPage*>(pTabPage)->SetWrtShell(pSh);
+    assert(pTabPage);
 
-    SetTabPage(pTabPage);
+    if (pTabPage)
+    {
+        static_cast<SwFldPage*>(pTabPage)->SetWrtShell(pSh);
+        SetTabPage(pTabPage);
+    }
 
     return pTabPage;
 }
commit 752b8ebb265938e1e6dc434b226cc0667d99cc1b
Author: Caolán McNamara <caolanm at redhat.com>
Date:   Mon Apr 7 20:47:10 2014 +0100

    coverity#705012 Explicit null dereferenced
    
    Change-Id: I49631808c1b7cfce100987cb53be36ab5c97a3af

diff --git a/sw/source/ui/dialog/docstdlg.cxx b/sw/source/ui/dialog/docstdlg.cxx
index 7cf70ba..a600788 100644
--- a/sw/source/ui/dialog/docstdlg.cxx
+++ b/sw/source/ui/dialog/docstdlg.cxx
@@ -114,6 +114,9 @@ void SwDocStatPage::Update()
 
     OSL_ENSURE( pSh, "Shell not found" );
 
+    if (!pSh)
+        return;
+
     SwWait aWait( *pSh->GetDoc()->GetDocShell(), true );
     pSh->StartAction();
     aDocStat = pSh->GetDoc()->GetUpdatedDocStat();
commit a5cbf54716d113ac12f2c845d7ef9e4e1da18724
Author: Caolán McNamara <caolanm at redhat.com>
Date:   Mon Apr 7 20:45:29 2014 +0100

    coverity#705007 Explicit null dereferenced
    
    Change-Id: Idc30796f0f5ebb56508339d03d318c8a582eb504

diff --git a/sw/source/core/uibase/app/appopt.cxx b/sw/source/core/uibase/app/appopt.cxx
index 6eba18e..8917790 100644
--- a/sw/source/core/uibase/app/appopt.cxx
+++ b/sw/source/core/uibase/app/appopt.cxx
@@ -422,12 +422,8 @@ SfxTabPage* SwModule::CreateTabPage( sal_uInt16 nId, Window* pParent, const SfxI
         case RID_SW_TP_HTML_CONTENT_OPT:
         {
             SwAbstractDialogFactory* pFact = SwAbstractDialogFactory::Create();
-            if ( pFact )
-            {
-                ::CreateTabPage fnCreatePage = pFact->GetTabPageCreatorFunc( nId );
-                if ( fnCreatePage )
-                    pRet = (*fnCreatePage)( pParent, rSet );
-            }
+            ::CreateTabPage fnCreatePage = pFact->GetTabPageCreatorFunc( nId );
+            pRet = (*fnCreatePage)( pParent, rSet );
             break;
         }
         case RID_SW_TP_HTML_OPTGRID_PAGE:
@@ -440,12 +436,8 @@ SfxTabPage* SwModule::CreateTabPage( sal_uInt16 nId, Window* pParent, const SfxI
         case RID_SW_TP_STD_FONT_CTL:
         {
             SwAbstractDialogFactory* pFact = SwAbstractDialogFactory::Create();
-            if ( pFact )
-            {
-                ::CreateTabPage fnCreatePage = pFact->GetTabPageCreatorFunc( nId );
-                if ( fnCreatePage )
-                    pRet = (*fnCreatePage)( pParent, rSet );
-            }
+            ::CreateTabPage fnCreatePage = pFact->GetTabPageCreatorFunc( nId );
+            pRet = (*fnCreatePage)( pParent, rSet );
             if(RID_SW_TP_STD_FONT != nId)
             {
                 aSet.Put (SfxUInt16Item(SID_FONTMODE_TYPE, RID_SW_TP_STD_FONT_CJK == nId ? FONT_GROUP_CJK : FONT_GROUP_CTL));
@@ -457,12 +449,8 @@ SfxTabPage* SwModule::CreateTabPage( sal_uInt16 nId, Window* pParent, const SfxI
         case RID_SW_TP_OPTPRINT_PAGE:
         {
             SwAbstractDialogFactory* pFact = SwAbstractDialogFactory::Create();
-            if ( pFact )
-            {
-                ::CreateTabPage fnCreatePage = pFact->GetTabPageCreatorFunc( nId );
-                if ( fnCreatePage )
-                    pRet = (*fnCreatePage)( pParent, rSet );
-            }
+            ::CreateTabPage fnCreatePage = pFact->GetTabPageCreatorFunc( nId );
+            pRet = (*fnCreatePage)( pParent, rSet );
             aSet.Put (SfxBoolItem(SID_FAX_LIST, true));
             pRet->PageCreated(aSet);
         }
@@ -471,12 +459,8 @@ SfxTabPage* SwModule::CreateTabPage( sal_uInt16 nId, Window* pParent, const SfxI
         case RID_SW_TP_OPTTABLE_PAGE:
         {
             SwAbstractDialogFactory* pFact = SwAbstractDialogFactory::Create();
-            if ( pFact )
-            {
-                ::CreateTabPage fnCreatePage = pFact->GetTabPageCreatorFunc( nId );
-                if ( fnCreatePage )
-                    pRet = (*fnCreatePage)( pParent, rSet );
-            }
+            ::CreateTabPage fnCreatePage = pFact->GetTabPageCreatorFunc( nId );
+            pRet = (*fnCreatePage)( pParent, rSet );
             SwView* pCurrView = GetView();
             if(pCurrView)
             {
@@ -500,13 +484,9 @@ SfxTabPage* SwModule::CreateTabPage( sal_uInt16 nId, Window* pParent, const SfxI
         case RID_SW_TP_MAILCONFIG:
         {
             SwAbstractDialogFactory* pFact = SwAbstractDialogFactory::Create();
-            if ( pFact )
-            {
-                ::CreateTabPage fnCreatePage = pFact->GetTabPageCreatorFunc( nId );
-                if ( fnCreatePage )
-                    pRet = (*fnCreatePage)( pParent, rSet );
-            }
-            if (pRet && (nId == RID_SW_TP_OPTSHDWCRSR || nId == RID_SW_TP_HTML_OPTSHDWCRSR))
+            ::CreateTabPage fnCreatePage = pFact->GetTabPageCreatorFunc( nId );
+            pRet = (*fnCreatePage)( pParent, rSet );
+            if (nId == RID_SW_TP_OPTSHDWCRSR || nId == RID_SW_TP_HTML_OPTSHDWCRSR)
             {
                 SwView* pCurrView = GetView();
                 if(pCurrView)
@@ -520,34 +500,22 @@ SfxTabPage* SwModule::CreateTabPage( sal_uInt16 nId, Window* pParent, const SfxI
         case  RID_SW_TP_OPTTEST_PAGE:
         {
             SwAbstractDialogFactory* pFact = SwAbstractDialogFactory::Create();
-            if ( pFact )
-            {
-                ::CreateTabPage fnCreatePage = pFact->GetTabPageCreatorFunc( nId );
-                if ( fnCreatePage )
-                    pRet = (*fnCreatePage)( pParent, rSet );
-            }
+            ::CreateTabPage fnCreatePage = pFact->GetTabPageCreatorFunc( nId );
+            pRet = (*fnCreatePage)( pParent, rSet );
             break;
         }
         case  RID_SW_TP_BACKGROUND:
         {
             SfxAbstractDialogFactory* pFact = SfxAbstractDialogFactory::Create();
-            if ( pFact )
-            {
-                ::CreateTabPage fnCreatePage = pFact->GetTabPageCreatorFunc( RID_SVXPAGE_BACKGROUND );
-                if ( fnCreatePage )
-                    pRet = (*fnCreatePage)( pParent, rSet );
-            }
+            ::CreateTabPage fnCreatePage = pFact->GetTabPageCreatorFunc( RID_SVXPAGE_BACKGROUND );
+            pRet = (*fnCreatePage)( pParent, rSet );
             break;
         }
         case RID_SW_TP_OPTCAPTION_PAGE:
         {
             SwAbstractDialogFactory* pFact = SwAbstractDialogFactory::Create();
-            if ( pFact )
-            {
-                ::CreateTabPage fnCreatePage = pFact->GetTabPageCreatorFunc( RID_SW_TP_OPTCAPTION_PAGE );
-                if ( fnCreatePage )
-                    pRet = (*fnCreatePage)( pParent, rSet );
-            }
+            ::CreateTabPage fnCreatePage = pFact->GetTabPageCreatorFunc( RID_SW_TP_OPTCAPTION_PAGE );
+            pRet = (*fnCreatePage)( pParent, rSet );
         }
         break;
     }
commit a1dd3f712d3954f65c7f6754c457f4eaaa1a3028
Author: Caolán McNamara <caolanm at redhat.com>
Date:   Mon Apr 7 20:41:24 2014 +0100

    coverity#704622 Explicit null dereferenced
    
    Change-Id: Ibde2c27791d1be30d6207a338367b6c433acfc0b

diff --git a/dbaccess/source/ui/querydesign/QueryDesignView.cxx b/dbaccess/source/ui/querydesign/QueryDesignView.cxx
index a921c7b..2f105d7 100644
--- a/dbaccess/source/ui/querydesign/QueryDesignView.cxx
+++ b/dbaccess/source/ui/querydesign/QueryDesignView.cxx
@@ -2184,8 +2184,8 @@ namespace
                         if ( nColumnRefPos >= 0 && static_cast<sal_uInt32>(nColumnRefPos) < pColumnRef->count() )
                             pParamRef = pColumnRef->getChild(nColumnRefPos);
 
-                        if (    SQL_ISRULE(pColumnRef,general_set_fct)
-                            &&  SQL_ISRULE(pParamRef,column_ref) )
+                        if ( SQL_ISRULE(pColumnRef,general_set_fct)
+                            && pParamRef &&  SQL_ISRULE(pParamRef,column_ref) )
                         {
                             // Check the parameters for Column references
                             InsertColumnRef(_pView,pParamRef,aColumnName,aColumnAlias,aTableRange,aInfo,pTabList);
commit 380d4600d73a2f57a93d841d5fdfdd0a042d5d39
Author: Caolán McNamara <caolanm at redhat.com>
Date:   Mon Apr 7 17:04:46 2014 +0100

    use TriState instead of sal_Bool as there's three possibilities
    
    Change-Id: If24d4cec9ef4369f20419fe70de7392614a35316

diff --git a/basctl/source/basicide/moduldlg.cxx b/basctl/source/basicide/moduldlg.cxx
index 3f2d2d2..ff1f06b 100644
--- a/basctl/source/basicide/moduldlg.cxx
+++ b/basctl/source/basicide/moduldlg.cxx
@@ -247,17 +247,16 @@ bool ExtTreeListBox::NotifyAcceptDrop( SvTreeListEntry* pEntry )
     return bValid;
 }
 
-sal_Bool ExtTreeListBox::NotifyMoving( SvTreeListEntry* pTarget, SvTreeListEntry* pEntry,
+TriState ExtTreeListBox::NotifyMoving( SvTreeListEntry* pTarget, SvTreeListEntry* pEntry,
                         SvTreeListEntry*& rpNewParent, sal_uLong& rNewChildPos )
 {
     return NotifyCopyingMoving( pTarget, pEntry,
                                     rpNewParent, rNewChildPos, true );
 }
 
-sal_Bool ExtTreeListBox::NotifyCopying( SvTreeListEntry* pTarget, SvTreeListEntry* pEntry,
+TriState ExtTreeListBox::NotifyCopying( SvTreeListEntry* pTarget, SvTreeListEntry* pEntry,
                         SvTreeListEntry*& rpNewParent, sal_uLong& rNewChildPos )
 {
-//  return false;   // how do I copy an SBX?!
     return NotifyCopyingMoving( pTarget, pEntry,
                                     rpNewParent, rNewChildPos, false );
 }
@@ -318,8 +317,7 @@ void Shell::CopyDialogResources(
     }
 }
 
-
-sal_Bool ExtTreeListBox::NotifyCopyingMoving( SvTreeListEntry* pTarget, SvTreeListEntry* pEntry,
+TriState ExtTreeListBox::NotifyCopyingMoving( SvTreeListEntry* pTarget, SvTreeListEntry* pEntry,
                         SvTreeListEntry*& rpNewParent, sal_uLong& rNewChildPos, sal_Bool bMove )
 {
     (void)pEntry;
@@ -460,14 +458,10 @@ sal_Bool ExtTreeListBox::NotifyCopyingMoving( SvTreeListEntry* pTarget, SvTreeLi
         }
     }
 
-    return 2;   // open...
+    return TRISTATE_INDET;   // open...
 }
 
-
 // OrganizeDialog
-
-
-
 OrganizeDialog::OrganizeDialog(Window* pParent, sal_Int16 tabId,
     EntryDescriptor& rDesc )
     : TabDialog( pParent, "OrganizeDialog",
diff --git a/basctl/source/basicide/moduldlg.hxx b/basctl/source/basicide/moduldlg.hxx
index aa5d651..d01c940 100644
--- a/basctl/source/basicide/moduldlg.hxx
+++ b/basctl/source/basicide/moduldlg.hxx
@@ -103,11 +103,11 @@ protected:
     virtual DragDropMode    NotifyStartDrag( TransferDataContainer& rData, SvTreeListEntry* pEntry ) SAL_OVERRIDE;
     virtual bool            NotifyAcceptDrop( SvTreeListEntry* pEntry ) SAL_OVERRIDE;
 
-    virtual sal_Bool    NotifyMoving( SvTreeListEntry* pTarget, SvTreeListEntry* pEntry,
+    virtual TriState    NotifyMoving( SvTreeListEntry* pTarget, SvTreeListEntry* pEntry,
                         SvTreeListEntry*& rpNewParent, sal_uLong& rNewChildPos ) SAL_OVERRIDE;
-    virtual sal_Bool    NotifyCopying( SvTreeListEntry* pTarget, SvTreeListEntry* pEntry,
+    virtual TriState    NotifyCopying( SvTreeListEntry* pTarget, SvTreeListEntry* pEntry,
                         SvTreeListEntry*& rpNewParent, sal_uLong& rNewChildPos ) SAL_OVERRIDE;
-    sal_Bool            NotifyCopyingMoving( SvTreeListEntry* pTarget, SvTreeListEntry* pEntry,
+    TriState            NotifyCopyingMoving( SvTreeListEntry* pTarget, SvTreeListEntry* pEntry,
                         SvTreeListEntry*& rpNewParent, sal_uLong& rNewChildPos, sal_Bool bMove );
 
 public:
diff --git a/cui/source/inc/cfg.hxx b/cui/source/inc/cfg.hxx
index 3cda9e4..8394617 100644
--- a/cui/source/inc/cfg.hxx
+++ b/cui/source/inc/cfg.hxx
@@ -328,10 +328,10 @@ public:
 
     virtual bool        NotifyAcceptDrop( SvTreeListEntry* pEntry ) SAL_OVERRIDE;
 
-    virtual sal_Bool        NotifyMoving( SvTreeListEntry*, SvTreeListEntry*,
+    virtual TriState    NotifyMoving( SvTreeListEntry*, SvTreeListEntry*,
                                       SvTreeListEntry*&, sal_uLong& ) SAL_OVERRIDE;
 
-    virtual sal_Bool        NotifyCopying( SvTreeListEntry*, SvTreeListEntry*,
+    virtual TriState    NotifyCopying( SvTreeListEntry*, SvTreeListEntry*,
                                        SvTreeListEntry*&, sal_uLong&) SAL_OVERRIDE;
 
     virtual DragDropMode    NotifyStartDrag(
@@ -553,10 +553,10 @@ public:
     Size            GetCheckBoxPixelSize() const
         { return m_aCheckBoxImageSizePixel; }
 
-    virtual sal_Bool    NotifyMoving(
+    virtual TriState NotifyMoving(
         SvTreeListEntry*, SvTreeListEntry*, SvTreeListEntry*&, sal_uLong& ) SAL_OVERRIDE;
 
-    virtual sal_Bool    NotifyCopying(
+    virtual TriState NotifyCopying(
         SvTreeListEntry*, SvTreeListEntry*, SvTreeListEntry*&, sal_uLong&) SAL_OVERRIDE;
 
     void            KeyInput( const KeyEvent& rKeyEvent ) SAL_OVERRIDE;
diff --git a/include/svtools/treelistbox.hxx b/include/svtools/treelistbox.hxx
index a8c072e..188cfb6 100644
--- a/include/svtools/treelistbox.hxx
+++ b/include/svtools/treelistbox.hxx
@@ -473,15 +473,15 @@ public:
     virtual SvTreeListEntry* CloneEntry( SvTreeListEntry* pSource );
     virtual SvTreeListEntry* CreateEntry() const; // To create new Entries
 
-    // Return value: sal_True == Ok, sal_False == Cancel, 2==some hack
-    virtual sal_Bool    NotifyMoving(
+    // Return value: TRISTATE_TRUE == Ok, TRISTATE_FALSE == Cancel, TRISTATE_INDET == Ok and Make visible moved entry
+    virtual TriState NotifyMoving(
         SvTreeListEntry*  pTarget,       // D'n'D DropPosition in this->GetModel()
         SvTreeListEntry*  pEntry,        // Entry to be moved from GetSourceListBox()->GetModel()
         SvTreeListEntry*& rpNewParent,   // New TargetParent
         sal_uLong&        rNewChildPos); // The TargetParent's position in Childlist
 
-    // Return value: sal_True == Ok, sal_False == Cancel, 2==some hack
-    virtual sal_Bool    NotifyCopying(
+    // Return value: TRISTATE_TRUE == Ok, TRISTATE_FALSE == Cancel, TRISTATE_INDET == Ok and Make visible moved entry
+    virtual TriState    NotifyCopying(
         SvTreeListEntry*  pTarget,       // D'n'D DropPosition in this->GetModel()
         SvTreeListEntry*  pEntry,        // Entry to be copied from GetSourceListBox()->GetModel()
         SvTreeListEntry*& rpNewParent,   // New TargetParent
diff --git a/sc/source/ui/dbgui/PivotLayoutTreeListBase.cxx b/sc/source/ui/dbgui/PivotLayoutTreeListBase.cxx
index 5e1f320..0ca94a7 100644
--- a/sc/source/ui/dbgui/PivotLayoutTreeListBase.cxx
+++ b/sc/source/ui/dbgui/PivotLayoutTreeListBase.cxx
@@ -53,17 +53,17 @@ bool ScPivotLayoutTreeListBase::NotifyAcceptDrop(SvTreeListEntry* /*pEntry*/)
     return true;
 }
 
-sal_Bool ScPivotLayoutTreeListBase::NotifyMoving(SvTreeListEntry* pTarget, SvTreeListEntry* pSource,
+TriState ScPivotLayoutTreeListBase::NotifyMoving(SvTreeListEntry* pTarget, SvTreeListEntry* pSource,
                                                 SvTreeListEntry*& /*rpNewParent*/, sal_uLong& /*rNewChildPos*/)
 {
     InsertEntryForSourceTarget(pSource, pTarget);
-    return sal_False;
+    return TRISTATE_FALSE;
 }
 
-sal_Bool ScPivotLayoutTreeListBase::NotifyCopying(SvTreeListEntry* /*pTarget*/, SvTreeListEntry* /*pSource*/,
+TriState ScPivotLayoutTreeListBase::NotifyCopying(SvTreeListEntry* /*pTarget*/, SvTreeListEntry* /*pSource*/,
                                                  SvTreeListEntry*& /*rpNewParent*/, sal_uLong& /*rNewChildPos*/)
 {
-    return sal_False;
+    return TRISTATE_FALSE;
 }
 
 bool ScPivotLayoutTreeListBase::HasEntry(SvTreeListEntry* pEntry)
diff --git a/sc/source/ui/inc/PivotLayoutTreeListBase.hxx b/sc/source/ui/inc/PivotLayoutTreeListBase.hxx
index 26d94a1..7564d36 100644
--- a/sc/source/ui/inc/PivotLayoutTreeListBase.hxx
+++ b/sc/source/ui/inc/PivotLayoutTreeListBase.hxx
@@ -46,9 +46,9 @@ public:
 
     virtual sal_Int8 AcceptDrop(const AcceptDropEvent& rEvent) SAL_OVERRIDE;
     virtual bool NotifyAcceptDrop(SvTreeListEntry* pEntry) SAL_OVERRIDE;
-    virtual sal_Bool NotifyMoving(SvTreeListEntry* pTarget, SvTreeListEntry* pSource,
+    virtual TriState NotifyMoving(SvTreeListEntry* pTarget, SvTreeListEntry* pSource,
                                   SvTreeListEntry*& rpNewParent, sal_uLong& rNewChildPos) SAL_OVERRIDE;
-    virtual sal_Bool NotifyCopying(SvTreeListEntry* pTarget, SvTreeListEntry* pSource,
+    virtual TriState NotifyCopying(SvTreeListEntry* pTarget, SvTreeListEntry* pSource,
                                    SvTreeListEntry*& rpNewParent, sal_uLong& rNewChildPos) SAL_OVERRIDE;
     virtual DragDropMode NotifyStartDrag(TransferDataContainer& aTransferDataContainer,
                                          SvTreeListEntry* pEntry) SAL_OVERRIDE;
diff --git a/sd/source/ui/dlg/sdtreelb.cxx b/sd/source/ui/dlg/sdtreelb.cxx
index 3282ba2..5849589 100644
--- a/sd/source/ui/dlg/sdtreelb.cxx
+++ b/sd/source/ui/dlg/sdtreelb.cxx
@@ -1455,10 +1455,7 @@ bool SdPageObjsTLB::PageBelongsToCurrentShow (const SdPage* pPage) const
     return bBelongsToShow;
 }
 
-
-
-
-sal_Bool SdPageObjsTLB::NotifyMoving(
+TriState SdPageObjsTLB::NotifyMoving(
     SvTreeListEntry* pTarget,
     SvTreeListEntry* pEntry,
     SvTreeListEntry*& rpNewParent,
@@ -1499,15 +1496,12 @@ sal_Bool SdPageObjsTLB::NotifyMoving(
             rNewChildPos += nCurEntrySelPos;
             nCurEntrySelPos++;
         }
-        return sal_True;
+        return TRISTATE_TRUE;
     }
     else
-        return sal_False;
+        return TRISTATE_FALSE;
 }
 
-
-
-
 SvTreeListEntry* SdPageObjsTLB::GetDropTarget (const Point& rLocation)
 {
     SvTreeListEntry* pEntry = SvTreeListBox::GetDropTarget(rLocation);
diff --git a/sd/source/ui/inc/sdtreelb.hxx b/sd/source/ui/inc/sdtreelb.hxx
index b433668..396352b 100644
--- a/sd/source/ui/inc/sdtreelb.hxx
+++ b/sd/source/ui/inc/sdtreelb.hxx
@@ -173,7 +173,7 @@ protected:
         reorders both the involved shapes in their page as well as the
         associated list box entries.
     */
-    virtual sal_Bool NotifyMoving(
+    virtual TriState NotifyMoving(
         SvTreeListEntry*  pTarget,
         SvTreeListEntry*  pEntry,
         SvTreeListEntry*& rpNewParent,
diff --git a/sfx2/source/dialog/templdlg.cxx b/sfx2/source/dialog/templdlg.cxx
index 0c85940..d1a91fb 100644
--- a/sfx2/source/dialog/templdlg.cxx
+++ b/sfx2/source/dialog/templdlg.cxx
@@ -563,7 +563,7 @@ bool StyleTreeListBox_Impl::Notify( NotifyEvent& rNEvt )
 
 
 
-sal_Bool StyleTreeListBox_Impl::NotifyMoving(SvTreeListEntry*  pTarget,
+TriState StyleTreeListBox_Impl::NotifyMoving(SvTreeListEntry*  pTarget,
                                          SvTreeListEntry*  pEntry,
                                          SvTreeListEntry*& rpNewParent,
                                          sal_uIntPtr& lPos)
@@ -574,7 +574,7 @@ sal_Bool StyleTreeListBox_Impl::NotifyMoving(SvTreeListEntry*  pTarget,
 */
 {
     if(!pTarget || !pEntry)
-        return sal_False;
+        return TRISTATE_FALSE;
     aParent = GetEntryText(pTarget);
     aStyle  = GetEntryText(pEntry);
     const bool bRet = (bool)aDropLink.Call(this);
@@ -587,11 +587,9 @@ sal_Bool StyleTreeListBox_Impl::NotifyMoving(SvTreeListEntry*  pTarget,
             GetEntryText(pTmpEntry),GetEntryText(pEntry)) < 0;
         pTmpEntry=NextSibling(pTmpEntry),lPos++) ;
 
-    return bRet ? (sal_Bool)2 : sal_False;
+    return bRet ? TRISTATE_INDET : TRISTATE_FALSE;
 }
 
-
-
 bool  StyleTreeListBox_Impl::ExpandingHdl()
 
 /*  [Description]
diff --git a/sfx2/source/inc/templdgi.hxx b/sfx2/source/inc/templdgi.hxx
index d5cc46f..3a34953 100644
--- a/sfx2/source/inc/templdgi.hxx
+++ b/sfx2/source/inc/templdgi.hxx
@@ -103,7 +103,7 @@ protected:
     virtual bool    DoubleClickHdl() SAL_OVERRIDE;
     virtual bool    ExpandingHdl() SAL_OVERRIDE;
     virtual void    ExpandedHdl() SAL_OVERRIDE;
-    virtual sal_Bool    NotifyMoving(SvTreeListEntry*  pTarget,
+    virtual TriState NotifyMoving(SvTreeListEntry*  pTarget,
                                      SvTreeListEntry*  pEntry,
                                      SvTreeListEntry*& rpNewParent,
                                      sal_uIntPtr&        rNewChildPos) SAL_OVERRIDE;
diff --git a/svtools/source/contnr/treelistbox.cxx b/svtools/source/contnr/treelistbox.cxx
index 8114e45..d27f7b6 100644
--- a/svtools/source/contnr/treelistbox.cxx
+++ b/svtools/source/contnr/treelistbox.cxx
@@ -561,14 +561,14 @@ void SvTreeListBox::NotifyRemoving( SvTreeListEntry* )
         - entry is inserted at the end of the target childlist
 */
 #ifdef DBG_UTIL
-sal_Bool SvTreeListBox::NotifyMoving(
+TriState SvTreeListBox::NotifyMoving(
     SvTreeListEntry*  pTarget,       // D&D dropping position in this->GetModel()
     SvTreeListEntry*  pEntry,        // entry that we want to move, from
                                  // GetSourceListBox()->GetModel()
     SvTreeListEntry*& rpNewParent,   // new target parent
     sal_uLong&        rNewChildPos)  // position in childlist of target parent
 #else
-sal_Bool SvTreeListBox::NotifyMoving(
+TriState SvTreeListBox::NotifyMoving(
     SvTreeListEntry*  pTarget,       // D&D dropping position in this->GetModel()
     SvTreeListEntry*,                // entry that we want to move, from
                                  // GetSourceListBox()->GetModel()
@@ -581,7 +581,7 @@ sal_Bool SvTreeListBox::NotifyMoving(
     {
         rpNewParent = 0;
         rNewChildPos = 0;
-        return true;
+        return TRISTATE_TRUE;
     }
     if ( !pTarget->HasChildren() && !pTarget->HasChildrenOnDemand() )
     {
@@ -600,10 +600,10 @@ sal_Bool SvTreeListBox::NotifyMoving(
         else
             rNewChildPos = TREELIST_APPEND;
     }
-    return true;
+    return TRISTATE_TRUE;
 }
 
-sal_Bool SvTreeListBox::NotifyCopying(
+TriState SvTreeListBox::NotifyCopying(
     SvTreeListEntry*  pTarget,       // D&D dropping position in this->GetModel()
     SvTreeListEntry*  pEntry,        // entry that we want to move, from
                                  // GetSourceListBox()->GetModel()
@@ -655,8 +655,8 @@ bool SvTreeListBox::CopySelection( SvTreeListBox* pSource, SvTreeListEntry* pTar
         pSourceEntry = *it;
         SvTreeListEntry* pNewParent = 0;
         sal_uLong nInsertionPos = TREELIST_APPEND;
-        sal_Bool bOk=NotifyCopying(pTarget,pSourceEntry,pNewParent,nInsertionPos);
-        if ( bOk )
+        TriState nOk = NotifyCopying(pTarget,pSourceEntry,pNewParent,nInsertionPos);
+        if ( nOk )
         {
             if ( bClone )
             {
@@ -673,7 +673,7 @@ bool SvTreeListBox::CopySelection( SvTreeListBox* pSource, SvTreeListEntry* pTar
         else
             bSuccess = false;
 
-        if( bOk == (sal_Bool)2 )  // HACK: make visible moved entry?
+        if (nOk == TRISTATE_INDET)  // HACK: make visible moved entry
             MakeVisible( pSourceEntry );
     }
     pModel->SetCloneLink( aCloneLink );
@@ -712,15 +712,15 @@ bool SvTreeListBox::MoveSelectionCopyFallbackPossible( SvTreeListBox* pSource, S
 
         SvTreeListEntry* pNewParent = 0;
         sal_uLong nInsertionPos = TREELIST_APPEND;
-        sal_Bool bOk = NotifyMoving(pTarget,pSourceEntry,pNewParent,nInsertionPos);
-        sal_Bool bCopyOk = bOk;
-        if ( !bOk && bAllowCopyFallback )
+        TriState nOk = NotifyMoving(pTarget,pSourceEntry,pNewParent,nInsertionPos);
+        TriState nCopyOk = nOk;
+        if ( !nOk && bAllowCopyFallback )
         {
             nInsertionPos = TREELIST_APPEND;
-            bCopyOk = NotifyCopying(pTarget,pSourceEntry,pNewParent,nInsertionPos);
+            nCopyOk = NotifyCopying(pTarget,pSourceEntry,pNewParent,nInsertionPos);
         }
 
-        if ( bOk || bCopyOk )
+        if ( nOk || nCopyOk )
         {
             if ( bClone )
             {
@@ -730,7 +730,7 @@ bool SvTreeListBox::MoveSelectionCopyFallbackPossible( SvTreeListBox* pSource, S
             }
             else
             {
-                if ( bOk )
+                if ( nOk )
                     pModel->Move(pSourceEntry, pNewParent, nInsertionPos);
                 else
                     pModel->Copy(pSourceEntry, pNewParent, nInsertionPos);
@@ -739,7 +739,7 @@ bool SvTreeListBox::MoveSelectionCopyFallbackPossible( SvTreeListBox* pSource, S
         else
             bSuccess = false;
 
-        if( bOk == (sal_Bool)2 )  // HACK: make moved entry visible?
+        if (nOk == TRISTATE_INDET)  // HACK: make moved entry visible
             MakeVisible( pSourceEntry );
     }
     pModel->SetCloneLink( aCloneLink );
diff --git a/sw/source/core/uibase/inc/conttree.hxx b/sw/source/core/uibase/inc/conttree.hxx
index 91da8b4..8ff2509 100644
--- a/sw/source/core/uibase/inc/conttree.hxx
+++ b/sw/source/core/uibase/inc/conttree.hxx
@@ -118,12 +118,12 @@ protected:
                                         SvTreeListEntry* ) SAL_OVERRIDE;
     virtual bool    NotifyAcceptDrop( SvTreeListEntry* ) SAL_OVERRIDE;
 
-    virtual sal_Bool    NotifyMoving(   SvTreeListEntry*  pTarget,
+    virtual TriState NotifyMoving(   SvTreeListEntry*  pTarget,
                                     SvTreeListEntry*  pEntry,
                                     SvTreeListEntry*& rpNewParent,
                                     sal_uLong&        rNewChildPos
                                 ) SAL_OVERRIDE;
-    virtual sal_Bool    NotifyCopying(  SvTreeListEntry*  pTarget,
+    virtual TriState NotifyCopying(  SvTreeListEntry*  pTarget,
                                     SvTreeListEntry*  pEntry,
                                     SvTreeListEntry*& rpNewParent,
                                     sal_uLong&        rNewChildPos
@@ -260,12 +260,12 @@ protected:
     virtual void    RequestHelp( const HelpEvent& rHEvt ) SAL_OVERRIDE;
 
     virtual sal_IntPtr GetTabPos( SvTreeListEntry*, SvLBoxTab* ) SAL_OVERRIDE;
-    virtual sal_Bool    NotifyMoving(   SvTreeListEntry*  pTarget,
+    virtual TriState NotifyMoving(   SvTreeListEntry*  pTarget,
                                     SvTreeListEntry*  pEntry,
                                     SvTreeListEntry*& rpNewParent,
                                     sal_uLong&        rNewChildPos
                                 ) SAL_OVERRIDE;
-    virtual sal_Bool    NotifyCopying(  SvTreeListEntry*  pTarget,
+    virtual TriState NotifyCopying(  SvTreeListEntry*  pTarget,
                                     SvTreeListEntry*  pEntry,
                                     SvTreeListEntry*& rpNewParent,
                                     sal_uLong&        rNewChildPos
diff --git a/sw/source/core/uibase/inc/glossary.hxx b/sw/source/core/uibase/inc/glossary.hxx
index af8a8ce..d44f5df 100644
--- a/sw/source/core/uibase/inc/glossary.hxx
+++ b/sw/source/core/uibase/inc/glossary.hxx
@@ -61,17 +61,17 @@ class SwGlTreeListBox : public SvTreeListBox
                                             SvTreeListEntry* ) SAL_OVERRIDE;
     virtual bool         NotifyAcceptDrop( SvTreeListEntry* ) SAL_OVERRIDE;
 
-    virtual sal_Bool    NotifyMoving(   SvTreeListEntry*  pTarget,
+    virtual TriState     NotifyMoving(   SvTreeListEntry*  pTarget,
                                     SvTreeListEntry*  pEntry,
                                     SvTreeListEntry*& rpNewParent,
                                     sal_uLong&        rNewChildPos
                                 ) SAL_OVERRIDE;
-    virtual sal_Bool    NotifyCopying(  SvTreeListEntry*  pTarget,
+    virtual TriState     NotifyCopying(  SvTreeListEntry*  pTarget,
                                     SvTreeListEntry*  pEntry,
                                     SvTreeListEntry*& rpNewParent,
                                     sal_uLong&        rNewChildPos) SAL_OVERRIDE;
 
-    sal_Bool NotifyCopyingOrMoving( SvTreeListEntry*  pTarget,
+    TriState NotifyCopyingOrMoving( SvTreeListEntry*  pTarget,
                                     SvTreeListEntry*  pEntry,
                                     bool              bIsMove);
 public:
diff --git a/sw/source/core/uibase/utlui/content.cxx b/sw/source/core/uibase/utlui/content.cxx
index 06adfaf..3225525 100644
--- a/sw/source/core/uibase/utlui/content.cxx
+++ b/sw/source/core/uibase/utlui/content.cxx
@@ -2483,7 +2483,7 @@ DragDropMode SwContentTree::NotifyStartDrag(
 }
 // After the drag the current paragraph will be moved  w i t h  the children.
 
-sal_Bool  SwContentTree::NotifyMoving( SvTreeListEntry*  pTarget,
+TriState SwContentTree::NotifyMoving( SvTreeListEntry*  pTarget,
         SvTreeListEntry*  pEntry, SvTreeListEntry*& , sal_uLong& )
 {
     if(!bDocChgdInDragging)
@@ -2515,12 +2515,12 @@ sal_Bool  SwContentTree::NotifyMoving( SvTreeListEntry*  pTarget,
         Display(true);
     }
     //TreeListBox will be reloaded from the document
-    return sal_False;
+    return TRISTATE_FALSE;
 }
 
 // After the drag the current paragraph will be moved  w i t h o u t  the children.
 
-sal_Bool  SwContentTree::NotifyCopying( SvTreeListEntry*  pTarget,
+TriState SwContentTree::NotifyCopying( SvTreeListEntry*  pTarget,
         SvTreeListEntry*  pEntry, SvTreeListEntry*& , sal_uLong& )
 {
     if(!bDocChgdInDragging)
@@ -2551,7 +2551,7 @@ sal_Bool  SwContentTree::NotifyCopying( SvTreeListEntry*  pTarget,
         aActiveContentArr[CONTENT_TYPE_OUTLINE]->Invalidate();
         Display(true);
     }
-    return sal_False;
+    return TRISTATE_FALSE;
 }
 
 // No drop before the first entry - it's a SwContentType
diff --git a/sw/source/core/uibase/utlui/glbltree.cxx b/sw/source/core/uibase/utlui/glbltree.cxx
index b72dfb3..e6e4ee0 100644
--- a/sw/source/core/uibase/utlui/glbltree.cxx
+++ b/sw/source/core/uibase/utlui/glbltree.cxx
@@ -533,7 +533,7 @@ sal_IntPtr SwGlobalTree::GetTabPos( SvTreeListEntry*, SvLBoxTab* pTab)
     return pTab->GetPos() - GLBL_TABPOS_SUB;
 }
 
-sal_Bool     SwGlobalTree::NotifyMoving(   SvTreeListEntry*  pTarget,
+TriState SwGlobalTree::NotifyMoving(   SvTreeListEntry*  pTarget,
                                         SvTreeListEntry*  pSource,
                                         SvTreeListEntry*&,
                                         sal_uLong&
@@ -547,16 +547,17 @@ sal_Bool     SwGlobalTree::NotifyMoving(   SvTreeListEntry*  pTarget,
             *pSwGlblDocContents, nSource, nSource + 1, nDest ) &&
             Update( sal_False ))
         Display();
-    return sal_False;
+
+    return TRISTATE_FALSE;
 }
 
-sal_Bool     SwGlobalTree::NotifyCopying(  SvTreeListEntry*  /*pTarget*/,
+TriState SwGlobalTree::NotifyCopying(  SvTreeListEntry*  /*pTarget*/,
                                         SvTreeListEntry*  /*pEntry*/,
                                         SvTreeListEntry*& /*rpNewParent*/,
                                         sal_uLong&        /*rNewChildPos*/
                                     )
 {
-    return sal_False;
+    return TRISTATE_FALSE;
 }
 
 bool SwGlobalTree::NotifyAcceptDrop( SvTreeListEntry* pEntry)
diff --git a/sw/source/ui/misc/glossary.cxx b/sw/source/ui/misc/glossary.cxx
index 0989836..b248508 100644
--- a/sw/source/ui/misc/glossary.cxx
+++ b/sw/source/ui/misc/glossary.cxx
@@ -936,7 +936,7 @@ bool SwGlTreeListBox::NotifyAcceptDrop( SvTreeListEntry* pEntry)
 
 }
 
-sal_Bool  SwGlTreeListBox::NotifyMoving(   SvTreeListEntry*  pTarget,
+TriState SwGlTreeListBox::NotifyMoving(   SvTreeListEntry*  pTarget,
                                     SvTreeListEntry*  pEntry,
                                     SvTreeListEntry*& /*rpNewParent*/,
                                     sal_uLong&        /*rNewChildPos*/
@@ -945,7 +945,7 @@ sal_Bool  SwGlTreeListBox::NotifyMoving(   SvTreeListEntry*  pTarget,
     return NotifyCopyingOrMoving(pTarget, pEntry, true);
 }
 
-sal_Bool  SwGlTreeListBox::NotifyCopying(   SvTreeListEntry*  pTarget,
+TriState SwGlTreeListBox::NotifyCopying(   SvTreeListEntry*  pTarget,
                                     SvTreeListEntry*  pEntry,
                                     SvTreeListEntry*& /*rpNewParent*/,
                                     sal_uLong&        /*rNewChildPos*/
@@ -954,7 +954,7 @@ sal_Bool  SwGlTreeListBox::NotifyCopying(   SvTreeListEntry*  pTarget,
     return NotifyCopyingOrMoving(pTarget, pEntry, false);
 }
 
-sal_Bool SwGlTreeListBox::NotifyCopyingOrMoving(
+TriState SwGlTreeListBox::NotifyCopyingOrMoving(
     SvTreeListEntry*  pTarget,
     SvTreeListEntry*  pEntry,
     bool              bIsMove)
@@ -1001,7 +1001,7 @@ sal_Bool SwGlTreeListBox::NotifyCopyingOrMoving(
             }
         }
     }
-    return sal_False; // otherwise the entry is being set automatically
+    return TRISTATE_FALSE; // otherwise the entry is being set automatically
 }
 
 OUString SwGlossaryDlg::GetCurrGrpName() const
commit 21c3f6ac12877bcd512aff0255078afaf4880f6a
Author: Caolán McNamara <caolanm at redhat.com>
Date:   Mon Apr 7 14:44:38 2014 +0100

    WaE: -Werror=uninitialized
    
    Change-Id: I4c2eb1e323505c6298203cb89769dc693f4e63bb

diff --git a/sfx2/source/appl/imestatuswindow.cxx b/sfx2/source/appl/imestatuswindow.cxx
index d38b690..717298d 100644
--- a/sfx2/source/appl/imestatuswindow.cxx
+++ b/sfx2/source/appl/imestatuswindow.cxx
@@ -109,7 +109,7 @@ bool ImeStatusWindow::isShowing()
 {
     try
     {
-        bool bShow;
+        bool bShow(0);
         if (getConfig()->getPropertyValue(OUString("ShowStatusWindow")) >>= bShow)
             return bShow;
     }


More information about the Libreoffice-commits mailing list
diff --git a/cui/source/customize/cfg.cxx b/cui/source/customize/cfg.cxx
index 20ea893..f39107b 100644
--- a/cui/source/customize/cfg.cxx
+++ b/cui/source/customize/cfg.cxx
@@ -1434,7 +1434,7 @@ bool SvxMenuEntriesListBox::NotifyAcceptDrop( SvTreeListEntry* )
     return true;
 }
 
-sal_Bool SvxMenuEntriesListBox::NotifyMoving(
+TriState SvxMenuEntriesListBox::NotifyMoving(
     SvTreeListEntry* pTarget, SvTreeListEntry* pSource,
     SvTreeListEntry*& rpNewParent, sal_uLong& rNewChildPos)
 {
@@ -1445,11 +1445,11 @@ sal_Bool SvxMenuEntriesListBox::NotifyMoving(
         {
             SvTreeListBox::NotifyMoving(
                 pTarget, pSource, rpNewParent, rNewChildPos );
-            return sal_True;
+            return TRISTATE_TRUE;
         }
         else
         {
-            return sal_False;
+            return TRISTATE_FALSE;
         }
     }
     else
@@ -1458,7 +1458,7 @@ sal_Bool SvxMenuEntriesListBox::NotifyMoving(
     }
 }
 
-sal_Bool SvxMenuEntriesListBox::NotifyCopying(
+TriState SvxMenuEntriesListBox::NotifyCopying(
     SvTreeListEntry* pTarget, SvTreeListEntry* pSource,
     SvTreeListEntry*& rpNewParent, sal_uLong& rNewChildPos)
 {
@@ -1471,13 +1471,13 @@ sal_Bool SvxMenuEntriesListBox::NotifyCopying(
         // if the target is NULL then add function to the start of the list
         pPage->AddFunction( pTarget, pTarget == NULL );
 
         // AddFunction already adds the listbox entry so return FALSE
         // to stop another listbox entry being added
-        return sal_False;
+        return TRISTATE_FALSE;
     }
 
     // Copying is only allowed from external controls, not within the listbox
-    return sal_False;
+    return TRISTATE_FALSE;
 }
 
 void SvxMenuEntriesListBox::KeyInput( const KeyEvent& rKeyEvent )
@@ -4660,11 +4660,11 @@ void SvxToolbarEntriesListBox::KeyInput( const KeyEvent& rKeyEvent )
     }
 }
 
-sal_Bool SvxToolbarEntriesListBox::NotifyMoving(
+TriState SvxToolbarEntriesListBox::NotifyMoving(
     SvTreeListEntry* pTarget, SvTreeListEntry* pSource,
     SvTreeListEntry*& rpNewParent, sal_uLong& rNewChildPos)
 {
-    bool result = SvxMenuEntriesListBox::NotifyMoving(
+    TriState result = SvxMenuEntriesListBox::NotifyMoving(
         pTarget, pSource, rpNewParent, rNewChildPos );
 
     if ( result )
@@ -4682,7 +4682,7 @@ sal_Bool SvxToolbarEntriesListBox::NotifyMoving(
     return result;
 }
 
-sal_Bool SvxToolbarEntriesListBox::NotifyCopying(
+TriState SvxToolbarEntriesListBox::NotifyCopying(
     SvTreeListEntry*  pTarget,
     SvTreeListEntry*  pSource,
     SvTreeListEntry*& rpNewParent,
@@ -4706,13 +4706,13 @@ sal_Bool SvxToolbarEntriesListBox::NotifyCopying(
             pSaveInData->ApplyToolbar( pToolbar );
         }
 
         // AddFunction already adds the listbox entry so return FALSE
         // to stop another listbox entry being added
-        return sal_False;
+        return TRISTATE_FALSE;
     }
 
     // Copying is only allowed from external controls, not within the listbox
-    return sal_False;
+    return TRISTATE_FALSE;
 }
 
 SvxNewToolbarDialog::SvxNewToolbarDialog(Window* pWindow, const OUString& rName)
@@ -1471,13 +1471,13 @@ sal_Bool SvxMenuEntriesListBox::NotifyCopying(
         pPage->AddFunction( pTarget, pTarget == NULL );
 
-        // AddFunction already adds the listbox entry so return FALSE
+        // AddFunction already adds the listbox entry so return TRISTATE_FALSE
         // to stop another listbox entry being added
@@ -4706,13 +4706,13 @@ sal_Bool SvxToolbarEntriesListBox::NotifyCopying(
         }
 
-        // AddFunction already adds the listbox entry so return FALSE
+        // AddFunction already adds the listbox entry so return TRISTATE_FALSE
         // to stop another listbox entry being added